**"Virtually Nonexistent": Gender and Racial Representation in Online Econ Lessons
*Caroline Krafft, Ashley McFarlane, Louise Ba, Karri Drain, Elizabeth Kula
*v7
*Original: 2020.07.21
*Updated: 2022.10.07

*Version
version 16.1

*Install programs
ssc install estout, replace
ssc install catplot, replace
net from http://www.stata.com
net cd users
net cd vwiggins
net install grc1leg

*********
*Data preparation
*********
cd "/Users/Caroline/Documents/My Publications/Data replications/EEJ 2022"

import excel "Data/Original data/econedlink_data4.xlsx", sheet("Sheet1") clear firstrow

*Drop blanks
drop Q-X
dropmiss *, obs force

replace grade = "9-12" if grade == "12sep2020" | grade == "12sep2021" | grade == "13sep2021" | grade == "14sep2021" | grade == "15sep2021"
replace grade = "6-8" if grade == "08jun2020" | grade== "08jun2021"
replace grade = "3-5" if grade == "05mar2020" | grade== "05mar2021"

*Renames
rename *, lower

rename examplename example_name
rename race example_race

*Drop variables not used
drop active_passive typeofbusinessleaderfortune economist_type linked party


********
*Checks
********
fre example_name if example_gender==""
fre example_name if example_race==""
fre real_fiction if example_race==""
fre example_name if example_race=="" & real_fiction=="Real"
fre example_name if real_fiction==""

********
*Outcomes
********

*Example female
gen example_female=1 if inlist(example_gender,"Female", "Woman", "woman")
replace example_female=0 if inlist(example_gender,"Male", "Man", "man")

*Check
tabu example_female example_gender, miss

*Example BIPOC
gen example_bipoc=1 if inlist(example_race,"African American", "Asian", "Black", "Latino", "Latinx", "Mexican","Native American")
replace example_bipoc=0 if inlist(example_race,"White", "Caucasian")

*Check
tabu example_bipoc example_race, miss

***Role 
*Fictional person
gen role=6 if real_fiction=="Fiction"
*Celebrity
replace role=5 if inlist(type, "Actor","Celebrity","Comedian","Musical Artist", "Professional Athlete","Professional Athlete ",  "Singer","athlete","Sports")
*Professional
replace role=4 if inlist(type,"Author/Journalist","Journalist", "Lawyer ","Other","Religious Leader","director for the National Parks and Conservation Association", "journalist", "scientist", "writer")
replace role=4 if inlist(type,"Writer","Retired", "Doctor","Medical patient")
*Politician
replace role=3 if inlist(type,"Founding Father", "Policy maker", "Policy Maker", "Policy-maker", "Political Activist","Politician","U.S. President", "politicians")
*Business
replace role=2 if inlist(type,"Business", "Business Leader", "Business leader", "Business-Leader", "Entrepreneur","Entreprenuer", "Inventor", "VP for kaiser","Sales Director")
*Economist (incl. one column typo, rechecked)
replace role=1 if inlist(type,"Economist", "Analyst", "Caucasian")

la def Lrole 6 "Fictional" 5 "Celebrity" 4 "Other" 3 "Policy-maker" 2 "Business" 1 "Economist"
la val role Lrole

fre role
tabu type role, miss

*Role of economist
gen role_econ=(role>=1 & role<=3) if role!=.

********
*Key covariates
********


*author female
gen author_female=1 if inlist(author_gender,"Female", "Mixed")
replace author_female=0 if inlist(author_gender,"Male")

*Check
tabu author_female author_gender, miss

*author BIPOC
gen author_bipoc=1 if inlist(author_race,"African American", "Asian", "Black", "Latino", "Latinx", "Mexican", "Bipoc", "Mixed", "Hispanic")
replace author_bipoc=0 if inlist(author_race,"White", "Caucasian", "caucasian")

*Check
tabu author_bipoc author_race, miss

*Keep example data

*N total
codebook link

keep if example_female!=.

save "Data/Analysis data/Representation_econ.dta", replace


**********
*Summary stats
**********


*Stat: Ns
fre example_female
fre example_bipoc
fre role
fre author_bipoc
fre author_race
fre author_female
fre author_gender
codebook link



**********
*H1, H2
**********

*Cenus: https://www.census.gov/quickfacts/fact/table/US/LFE046220
*H1
prtest example_female=.505
*H2
prtest example_bipoc=.407

**********
*H3, H4
**********

*H3
prtest role_econ, by(example_female)

*H4 
prtest role_econ, by(example_bipoc)

tabu role_econ example_female, row nofreq
tabu role example_female, row nofreq
tabu role_econ example_bipoc, row nofreq

**********
*H5, H6
**********

*ExampleFemalei=ß₀ +ß₁AuthorFemalei+εi
reg example_female i.author_female

estimates store est_female

*ExampleBIPOCi=ß₀ +ß₁AuthorBIPOCi+εi
reg example_bipoc i.author_bipoc

estimates store est_bipoc


**********
*Graphs
**********

***Figure 2

set scheme s1mono
graph set window fontface "Arial"

***Visual of roles 
catplot role, percent(example_female) over(example_female, relabel(1 "Male example" 2 "Female example") label(labsize(4))) stack asy ylabel(0(20)100, nogrid) blabel(bar, pos(center) format(%9.0f) size(4)) ytitle("Percentage") l1title("") legend(row(2) span) bar(1, bcolor(gs5)) bar(2, bcolor(gs7)) bar(3, bcolor(gs9)) bar(4, bcolor(gs11)) bar(5, bcolor(gs13)) bar(6, bcolor(gs15))

graph save "Graphs and Tables/female role.gph", replace
graph export "Graphs and Tables/female role.jpg", replace width(1500)

catplot role, percent(example_bipoc) over(example_bipoc, relabel(1 "White example" 2 "BIPOC example") label(labsize(4))) stack asy ylabel(0(20)100, nogrid) blabel(bar, pos(center) format(%9.0f) size(4)) ytitle("Percentage") l1title("") legend(row(2) span) bar(1, bcolor(gs5)) bar(2, bcolor(gs7)) bar(3, bcolor(gs9)) bar(4, bcolor(gs11)) bar(5, bcolor(gs13)) bar(6, bcolor(gs15))

graph save "Graphs and Tables/bipoc role.gph", replace
graph export "Graphs and Tables/bipoc role.jpg", replace width(1500)

grc1leg "Graphs and Tables/female role.gph" "Graphs and Tables/bipoc role.gph", row(2)

graph save "Graphs and Tables/role.gph", replace
graph export "Graphs and Tables/role.jpg", replace width(1500)



***Table 1


esttab est_female est_bipoc using "Graphs and Tables/regressions.csv", cells(b(star fmt(%9.3f)) se(par))stats(N r2, fmt(%9.0g %9.3g) labels("N obs." "R-sq.")) nobase noomit refcat(1.author_female "Author gender (male omit.)" 1.author_bipoc "Author race (white omit.)", nolabel) mlabel("Example female" "Example BIPOC") varlabel(1.author_female "Author female/mixed" 1.author_bipoc "Author BIPOC/mixed" _cons "Constant") replace


***Visual of % female, BIPOC

foreach var of varlist example_female example_bipoc author_bipoc author_female {
	replace `var'=`var'*100
}

****Figure 1

graph hbar (mean) example_female example_bipoc author_female author_bipoc, asc ytitle("Percentage") ylabel(0(20)100, nogrid) blabel(bar, format(%9.0f)) yvaroptions(relabel(1 "Example female" 2 "Example BIPOC" 3 "Author female/mixed" 4 "Author BIPOC/mixed"))

graph save "Graphs and Tables/desc graph.gph", replace
graph export "Graphs and Tables/desc graph.jpg", replace width(1500)




